Bobby R. Bruce has submitted this change. ( https://gem5-review.googlesource.com/c/public/gem5/+/38315 )

Change subject: tests,arch-arm: Replaced X86 clang fast build for ARM_MESI_THREE
......................................................................

tests,arch-arm: Replaced X86 clang fast build for ARM_MESI_THREE

Given ARM_MESI_THREE_Level_HTM is a superset of ARM, it is logical to
compile it with clang and with 'fast' compiler optimizations when
checking for errors. This increases our test coverage

Change-Id: I320291cd543e5db8f543edd81facc91f3f52e17b
Reviewed-on: https://gem5-review.googlesource.com/c/public/gem5/+/38315
Reviewed-by: Bobby R. Bruce <bbr...@ucdavis.edu>
Maintainer: Bobby R. Bruce <bbr...@ucdavis.edu>
Tested-by: kokoro <noreply+kok...@google.com>
---
M tests/jenkins/presubmit.sh
1 file changed, 5 insertions(+), 4 deletions(-)

Approvals:
  Bobby R. Bruce: Looks good to me, approved; Looks good to me, approved
  kokoro: Regressions pass



diff --git a/tests/jenkins/presubmit.sh b/tests/jenkins/presubmit.sh
index 7b59f55..e7274ee 100755
--- a/tests/jenkins/presubmit.sh
+++ b/tests/jenkins/presubmit.sh
@@ -65,10 +65,11 @@

 # DOCKER_IMAGE_ALL_DEP compiles gem5.opt with GCC. We run a compilation of
 # gem5.fast on the Clang compiler to ensure changes are compilable with the
 # clang compiler. Due to the costs of compilation, we only compile X86
 # at this point. Further compiler tests are carried out as part of our weekly
 # "Compiler Checks" tests: http://jenkins.gem5.org/job/Compiler-Checks.
 rm -rf build
 docker run -u $UID:$GID --volume $(pwd):$(pwd) -w $(pwd) --rm \
     "${DOCKER_IMAGE_CLANG_COMPILE}" /usr/bin/env python3 /usr/bin/scons \
-    build/X86/gem5.fast -j4 --no-compress-debug
+    build/ARM_MESI_Three_Level_HTM/gem5.fast -j4 --no-compress-debug
@@ -65,10 +65,11 @@
 # DOCKER_IMAGE_ALL_DEP compiles gem5.opt with GCC. We run a compilation of
 # gem5.fast on the Clang compiler to ensure changes are compilable with the
-# clang compiler. Due to the costs of compilation, we only compile X86
-# at this point. Further compiler tests are carried out as part of our weekly
-# "Compiler Checks" tests: http://jenkins.gem5.org/job/Compiler-Checks.
+# clang compiler. Due to the costs of compilation, we only compile
+# ARM_MESI_Three_Level_HTM at this point. Further compiler tests are carried
+# out as part of our weekly "Compiler Checks" tests:
+# http://jenkins.gem5.org/job/Compiler-Checks.
 rm -rf build
 docker run -u $UID:$GID --volume $(pwd):$(pwd) -w $(pwd) --rm \

--
To view, visit https://gem5-review.googlesource.com/c/public/gem5/+/38315
To unsubscribe, or for help writing mail filters, visit https://gem5-review.googlesource.com/settings

Gerrit-Project: public/gem5
Gerrit-Branch: develop
Gerrit-Change-Id: I320291cd543e5db8f543edd81facc91f3f52e17b
Gerrit-Change-Number: 38315
Gerrit-PatchSet: 8
Gerrit-Owner: Bobby R. Bruce <bbr...@ucdavis.edu>
Gerrit-Reviewer: Andreas Sandberg <andreas.sandb...@arm.com>
Gerrit-Reviewer: Bobby R. Bruce <bbr...@ucdavis.edu>
Gerrit-Reviewer: Gabe Black <gabe.bl...@gmail.com>
Gerrit-Reviewer: Giacomo Travaglini <giacomo.travagl...@arm.com>
Gerrit-Reviewer: Jason Lowe-Power <power...@gmail.com>
Gerrit-Reviewer: Kyle Roarty <kyleroarty1...@gmail.com>
Gerrit-Reviewer: Matt Sinclair <mattdsincl...@gmail.com>
Gerrit-Reviewer: Matthew Poremba <matthew.pore...@amd.com>
Gerrit-Reviewer: kokoro <noreply+kok...@google.com>
Gerrit-MessageType: merged
_______________________________________________
gem5-dev mailing list -- gem5-dev@gem5.org
To unsubscribe send an email to gem5-dev-le...@gem5.org
%(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s

Reply via email to